@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 import abc
-from typing import Union, List
+from typing import Union
 
 from pydantic import BaseModel
 
